========
 Client
========

Gnocchi currently only provides a Python client and SDK which can be installed
using *pip*::

  pip install gnocchiclient

This package provides the `gnocchi` command line tool that can be used to send
requests to Gnocchi. You can read the `full documentation online`_.

.. _full documentation online: http://gnocchi.xyz/gnocchiclient
